@@ -2,6 +2,5 @@
 ## this is not a test in itself, don't execute
 ## this is a script that is executed by a test
 
-use Test::More 'no_plan';
-use Find::Lib '../t/mylib', 'MyLib';
+use Find::Lib '../t/mylib', 'MyLibNoTest';
 exit 0;
